==> flare-engine_0.19.orig.tar.gz: flare-engine-0.19/src/NPCManager.h <==
/*
Copyright © 2011-2012 Clint Bellanger

This file is part of FLARE.

FLARE is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

FLARE is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
FLARE.  If not, see http://www.gnu.org/licenses/
*/

/**
 * class NPCManager
 *
 * NPCs which are not combatative enemies are handled by this Manager.
 * Most commonly this involves vendor and conversation townspeople.
 */

#pragma once
#ifndef NPC_MANAGER_H
#define NPC_MANAGER_H

#include "CommonIncludes.h"
#include "TooltipData.h"

class StatBlock;
class NPC;
class WidgetTooltip;

class NPCManager {
private:
	WidgetTooltip *tip;
	StatBlock *stats;
	TooltipData tip_buf;
	int tooltip_margin;

public:
	NPCManager(StatBlock *stats);
	NPCManager(const NPCManager &copy); // not implemented
	~NPCManager();

	std::vector<NPC*> npcs;
	void handleNewMap();
	void logic();
	void addRenders(std::vector<Renderable> &r);
	int getID(std::string npcName);
	int checkNPCClick(Point mouse, FPoint cam);
	int getNearestNPC(FPoint pos);
	void renderTooltips(FPoint cam, Point mouse, int nearest);
};

#endif

==> flare-engine_1.14.orig.tar.gz: flare-engine-1.14/src/NPCManager.h <==
/*
Copyright © 2011-2012 Clint Bellanger
Copyright © 2012-2016 Justin Jacobs

This file is part of FLARE.

FLARE is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

FLARE is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
FLARE.  If not, see http://www.gnu.org/licenses/
*/

/**
 * class NPCManager
 *
 * NPCs which are not combatative enemies are handled by this Manager.
 * Most commonly this involves vendor and conversation townspeople.
 */

#ifndef NPC_MANAGER_H
#define NPC_MANAGER_H

#include "CommonIncludes.h"
#include "TooltipData.h"

class StatBlock;
class NPC;
class WidgetTooltip;
class Entity;

class NPCManager {
private:
	WidgetTooltip *tip;
	TooltipData tip_buf;

public:
	explicit NPCManager();
	NPCManager(const NPCManager &copy); // not implemented
	~NPCManager();

	std::vector<NPC*> npcs;
	void handleNewMap();
	void createMapEvent(const NPC& npc, size_t _npcs);
	void logic();
	void addRenders(std::vector<Renderable> &r);
	int getID(const std::string& npcName);
	Entity* npcFocus(const Point& mouse, const FPoint& cam, bool alive_only);
	Entity* getNearestNPC(const FPoint& pos, bool get_corpse = false);
};

#endif
